@@ -403,7 +403,7 @@ class Candidate(Your):
         else:
             x = time_series
         argmax = np.argmax(x)
-        mask = np.ones(len(x), dtype=np.bool)
+        mask = np.ones(len(x), dtype=np.bool_)
         mask[argmax - self.width // 2 : argmax + self.width // 2] = 0
         x -= x[mask].mean()
         std = np.std(x[mask])
